"""Setup tool for cz_ai_conventional"""
import os
from rich import print
from .version import VERSION

def setup_commitizen():
    """Setup global configuration for commitizen"""
    try:
        home = os.path.expanduser("~")
        config_dir = os.path.join(home, ".commitizen")
        config_file = os.path.join(config_dir, "config.toml")
        
        if not os.path.exists(config_dir):
            os.makedirs(config_dir)
        
        config_content = f"""
[settings]
name = "cz_ai_conventional"
version = "{VERSION}"

[commitizen]
name = "cz_ai_conventional"
version = "{VERSION}"
tag_format = "v$version"
"""
        with open(config_file, "w") as f:
            f.write(config_content.strip())
        
        print('[green]Configuración global de commitizen instalada correctamente[/green]')
        return True
    except Exception as e:
        print(f'[red]Error al configurar commitizen: {e}[/red]')
        return False

def main():
    """Entry point for setup tool"""
    setup_commitizen()

if __name__ == "__main__":
    main() 